==> 0.2.23.tar.gz: lib/pages/comments/widgets/message_reply.dart <==
import 'package:feed_plugin/models/post_comment_model.dart';
import 'package:feed_plugin/models/replyCommentModel.dart';
import 'package:feed_plugin/repo/feed_repository.dart';
import 'package:feed_plugin/service/http_service.dart';
import 'package:feed_plugin/widgets/default_profile_img.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/screen_util.dart';
import 'package:timeago/timeago.dart' as timeago;

class MessagesReply extends StatefulWidget {
  const MessagesReply({
    Key key,
    @required this.replyCommentModel,
    @required this.isUserMassage,
    @required this.commentId,
    @required this.loc,
  }) : super(key: key);

  final ReplyCommentModel replyCommentModel;
  final bool isUserMassage;
  final int commentId;
  final loc;

  @override
  _MessagesReplyState createState() => _MessagesReplyState();
}

class _MessagesReplyState extends State<MessagesReply> {
  bool deleteComment = false;
  HttpService httpService;
  FeedRepository feedRepository;

  @override
  void initState() {
    super.initState();
    httpService = HttpService("gogog");
    feedRepository = FeedRepository(httpService);
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    final date2 = DateTime.now();
    final difference =
        date2.difference(this.widget.replyCommentModel.createdAt).inMinutes;
    final fifteenAgo =
        new DateTime.now().subtract(new Duration(minutes: difference));

    return GestureDetector(
      onLongPress: () {
        if (this.widget.isUserMassage) {
          this.setState(() {
            deleteComment = true;
          });
          showDialog(
              context: context,
              barrierDismissible: false,
              builder: (BuildContext context) {
                var dialogContext = context;
                return AlertDialog(
                  content: Text(this.widget.loc.translate(
                      "Are you sure you want to delete this comment?")),
                  actions: [
                    TextButton(
                      onPressed: () {
                        this.setState(() {
                          deleteComment = false;
                        });
                        Navigator.of(dialogContext).pop();
                      },
                      child: Text(this.widget.loc.translate("Cancel")),
                    ),
                    TextButton(
                      onPressed: () {
                        feedRepository
                            .removeReplyComment(this.widget.commentId)
                            .then((value) => {
                                  this.setState(() {
                                    deleteComment = false;
                                  }),
                                  Navigator.of(dialogContext).pop(),
                                });
                      },
                      child: Text(this.widget.loc.translate("Ok")),
                    ),
                  ],
                );
              });
        }
      },
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Column(
            children: [
              Padding(
                padding: EdgeInsets.only(left: ScreenUtil().setWidth(16)),
                child: this.widget.replyCommentModel.user.profileImg == null ||
                        this.widget.replyCommentModel.user.profileImg ==
                            "null" ||
                        this.widget.replyCommentModel.user.profileImg == ""
                    ? DefaultProfileImg(
                        firstName: this.widget.replyCommentModel.user.firstName,
                        lastName: this.widget.replyCommentModel.user.lastName,
                        heightProfileImage: 39,
                        widthProfileImage: 38,
                      )
                    : ClipOval(
                        child: Image.network(
                          this.widget.replyCommentModel.user.profileImg,
                          width: ScreenUtil().setWidth(38),
                          height: ScreenUtil().setWidth(39),
                          fit: BoxFit.cover,
                        ),
                      ),
              ),
            ],
          ),
          Padding(
            padding: EdgeInsets.only(left: ScreenUtil().setWidth(5)),
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Padding(
                  padding: EdgeInsets.only(
                    left: ScreenUtil().setWidth(8),
                    right: ScreenUtil().setWidth(16),
                  ),
                  child: Container(
                    margin: EdgeInsets.only(bottom: ScreenUtil().setHeight(5)),
                    width: ScreenUtil().setWidth(250),
                    decoration: BoxDecoration(
                      color: deleteComment ? Colors.grey : Color(0xffE8ECEF),
                      borderRadius: BorderRadius.circular(10),
                      boxShadow: [
                        BoxShadow(
                          color: Colors.white70,
                          blurRadius: 0,
                          offset: Offset(5, 5),
                        ),
                      ],
                    ),
                    child: Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        Row(children: [
                          Padding(
                            padding: EdgeInsets.only(
                                left: ScreenUtil().setWidth(15),
                                top: ScreenUtil().setWidth(9)),
                            child: Text(
                              this.widget.replyCommentModel.user.lastName !=
                                          null &&
                                      this
                                              .widget
                                              .replyCommentModel
                                              .user
                                              .lastName !=
                                          "null"
                                  ? this
                                          .widget
                                          .replyCommentModel
                                          .user
                                          .firstName
                                          .toString() +
                                      " " +
                                      this
                                          .widget
                                          .replyCommentModel
                                          .user
                                          .lastName
                                          .toString()
                                  : this
                                      .widget
                                      .replyCommentModel
                                      .user
                                      .firstName
                                      .toString(),
                              style:
                                  TextStyle(fontSize: ScreenUtil().setSp(12)),
                            ),
                          ),
                          Padding(
                            padding:
                                EdgeInsets.only(top: ScreenUtil().setWidth(9)),
                            child: Text(
                              " -" +
                                  timeago.format(fifteenAgo,
                                      locale: 'en_short'),
                              style: TextStyle(
                                  color: Color(0xff98A9BC),
                                  fontSize: ScreenUtil().setSp(12)),
                            ),
                          )
                        ]),
                        Padding(
                          padding:
                              EdgeInsets.only(left: ScreenUtil().setWidth(15)),
                          child: Text(
                              widget.replyCommentModel.user.about != "null" &&
                                      widget.replyCommentModel.user.about !=
                                          null
                                  ? this.widget.replyCommentModel.user.about
                                  : "",
                              style: TextStyle(
                                  color: Color(0xff98A9BC),
                                  fontSize: ScreenUtil().setSp(12))),
                        ),
                        // Text(""),
                        Padding(
                          padding: EdgeInsets.only(
                            bottom: ScreenUtil().setWidth(8),
                            left: ScreenUtil().setWidth(15),
                            right: ScreenUtil().setWidth(15),
                          ),
                          child: Text(
                            this.widget.replyCommentModel.comment,
                            style: TextStyle(
                              fontSize: ScreenUtil().setSp(14),
                            ),
                          ),
                        ),
                      ],
                    ),
                  ),
                ),
              ],
            ),
          ),
        ],
      ),
    );
  }
}

==> 0.3.23+1.tar.gz: lib/pages/comments/widgets/message_reply.dart <==
import 'package:feed_plugin/models/post_comment_model.dart';
import 'package:feed_plugin/models/replyCommentModel.dart';
import 'package:feed_plugin/repo/feed_repository.dart';
import 'package:feed_plugin/service/http_service.dart';
import 'package:feed_plugin/utilities/colors.dart';
import 'package:feed_plugin/widgets/default_profile_img.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:timeago/timeago.dart' as timeago;

class MessagesReply extends StatefulWidget {
  const MessagesReply({
    Key? key,
    required this.replyCommentModel,
    required this.isUserMassage,
    required this.commentId,
    required this.loc,
  }) : super(key: key);

  final ReplyCommentModel replyCommentModel;
  final bool isUserMassage;
  final int? commentId;
  final loc;

  @override
  _MessagesReplyState createState() => _MessagesReplyState();
}

class _MessagesReplyState extends State<MessagesReply> {
  bool deleteComment = false;
  late HttpService httpService;
  late FeedRepository feedRepository;

  @override
  void initState() {
    super.initState();
    httpService = HttpService("gogog");
    feedRepository = FeedRepository(httpService);
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    final date2 = DateTime.now();
    final difference =
        date2.difference(this.widget.replyCommentModel.createdAt!).inMinutes;
    final fifteenAgo =
        new DateTime.now().subtract(new Duration(minutes: difference));

    return GestureDetector(
      onLongPress: () {
        if (this.widget.isUserMassage) {
          this.setState(() {
            deleteComment = true;
          });
          showDialog(
              context: context,
              barrierDismissible: false,
              builder: (BuildContext context) {
                var dialogContext = context;
                return AlertDialog(
                  content: Text(this.widget.loc.translate(
                      "Are you sure you want to delete this comment?")),
                  actions: [
                    TextButton(
                      onPressed: () {
                        this.setState(() {
                          deleteComment = false;
                        });
                        Navigator.of(dialogContext).pop();
                      },
                      child: Text(this.widget.loc.translate("Cancel")),
                    ),
                    TextButton(
                      onPressed: () {
                        feedRepository
                            .removeReplyComment(this.widget.commentId)
                            .then((value) => {
                                  this.setState(() {
                                    deleteComment = false;
                                  }),
                                  Navigator.of(dialogContext).pop(),
                                });
                      },
                      child: Text(this.widget.loc.translate("Ok")),
                    ),
                  ],
                );
              });
        }
      },
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Column(
            children: [
              Padding(
                padding: EdgeInsets.only(left: ScreenUtil().setWidth(16)),
                child: this.widget.replyCommentModel.user!.profileImg == null ||
                        this.widget.replyCommentModel.user!.profileImg ==
                            "null" ||
                        this.widget.replyCommentModel.user!.profileImg == ""
                    ? DefaultProfileImg(
                        firstName: this.widget.replyCommentModel.user!.firstName,
                        lastName: this.widget.replyCommentModel.user!.lastName,
                        heightProfileImage: 39,
                        widthProfileImage: 38,
                      )
                    : ClipOval(
                        child: Image.network(
                          this.widget.replyCommentModel.user!.profileImg!,
                          width: ScreenUtil().setWidth(38),
                          height: ScreenUtil().setWidth(39),
                          fit: BoxFit.cover,
                        ),
                      ),
              ),
            ],
          ),
          Padding(
            padding: EdgeInsets.only(left: ScreenUtil().setWidth(5)),
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Padding(
                  padding: EdgeInsets.only(
                    left: ScreenUtil().setWidth(8),
                    right: ScreenUtil().setWidth(16),
                  ),
                  child: Container(
                    margin: EdgeInsets.only(bottom: ScreenUtil().setHeight(5)),
                    width: ScreenUtil().setWidth(250),
                    decoration: BoxDecoration(
                      color: deleteComment ? Colors.grey : Color(0xffE8ECEF),
                      borderRadius: BorderRadius.circular(10),
                      boxShadow: [
                        BoxShadow(
                          color: Colors.white70,
                          blurRadius: 0,
                          offset: Offset(5, 5),
                        ),
                      ],
                    ),
                    child: Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        Row(children: [
                          Padding(
                            padding: EdgeInsets.only(
                                left: ScreenUtil().setWidth(15),
                                top: ScreenUtil().setWidth(9)),
                            child: Text(
                              this.widget.replyCommentModel.user!.lastName !=
                                          null &&
                                      this
                                              .widget
                                              .replyCommentModel
                                              .user!
                                              .lastName !=
                                          "null"
                                  ? this
                                          .widget
                                          .replyCommentModel
                                          .user!
                                          .firstName
                                          .toString() +
                                      " " +
                                      this
                                          .widget
                                          .replyCommentModel
                                          .user!
                                          .lastName
                                          .toString()
                                  : this
                                      .widget
                                      .replyCommentModel
                                      .user!
                                      .firstName
                                      .toString(),
                              style:
                                  TextStyle(fontSize: ScreenUtil().setSp(12)),
                            ),
                          ),
                          Padding(
                            padding:
                                EdgeInsets.only(top: ScreenUtil().setWidth(9)),
                            child: Text(
                              " -" +
                                  timeago.format(fifteenAgo,
                                      locale: 'en_short'),
                              style: TextStyle(
                                  color: feedCalendarGreyColor,
                                  fontSize: ScreenUtil().setSp(12)),
                            ),
                          )
                        ]),
                        Padding(
                          padding:
                              EdgeInsets.only(left: ScreenUtil().setWidth(15)),
                          child: Text(
                              widget.replyCommentModel.user!.about != "null" &&
                                      widget.replyCommentModel.user!.about !=
                                          null
                                  ? this.widget.replyCommentModel.user!.about!
                                  : "",
                              style: TextStyle(
                                  color:feedCalendarGreyColor,
                                  fontSize: ScreenUtil().setSp(12))),
                        ),
                        // Text(""),
                        Padding(
                          padding: EdgeInsets.only(
                            bottom: ScreenUtil().setWidth(8),
                            left: ScreenUtil().setWidth(15),
                            right: ScreenUtil().setWidth(15),
                          ),
                          child: Text(
                            this.widget.replyCommentModel.comment!,
                            style: TextStyle(
                              fontSize: ScreenUtil().setSp(14),
                            ),
                          ),
                        ),
                      ],
                    ),
                  ),
                ),
              ],
            ),
          ),
        ],
      ),
    );
  }
}
